@@ -10,7 +10,7 @@ test_that("nlsTracePlot() test messages",{
   # no fun
   expect_error(nlsTracePlot(fit1),"missing, with no default")
   # bad pallette choice
-  expect_error(nlsTracePlot(fit1,vb1,pal="derek"),"should be one of")
+  expect_error(nlsTracePlot(fit1,vb1,col="derek"),"is not a valid color or palette")
   # bad n
   expect_error(nlsTracePlot(fit1,vb1,n=1),"'n' must be greater than 2")
   # bad legend
@@ -27,7 +27,7 @@ test_that("nlsTracePlot() test output",{
   # unsuccessful fit
   if (require(FSAdata)) {
     data(BSkateGB,package="FSAdata")
-    wtr <- filterD(BSkateGB,season=="winter")
+    wtr <- droplevels(subset(BSkateGB,season=="winter"))
     bh1 <- srFuns()
     trc <- capture.output(try(
       expect_error(fit2 <- nls(recruits~bh1(spawners,a,b),wtr,
